@@ -155,7 +155,7 @@ class TEI:
         Returns:
             Article
         """
-        from .models import Article
+        from .models import Article, ArticleCitations
 
         soup = BeautifulSoup(stream, "lxml")
         sentences = soup.find("s") is not None
@@ -173,10 +173,10 @@ class TEI:
 
         listBibl = soup.find("listbibl")
         if listBibl:
-            art.citations = []
+            art.citations = ArticleCitations()
             for struct in listBibl.find_all("biblstruct"):
-                art.citations.append(TEI.citation(struct))
-
+                name = struct.get("xml:id")
+                art.citations.additional_properties[name] = TEI.citation(struct)
         return art
 
     @staticmethod
@@ -335,9 +335,9 @@ class TEI:
                         sents = []
                         for s in p.children:
                             if isinstance(s, Tag) and s.name == "s":
-                                sec.paragraphs.append(TEI.text_with_refs(s))
+                                sents.append(TEI.text_with_refs(s))
                             else:
-                                sec.paragraphs.append(TextWithRefs(text=str(s)))
+                                sents.append(TextWithRefs(text=str(s)))
                         sec.paragraphs.append(sents)
                     else:
                         sec.paragraphs.append([TextWithRefs(text=str(p))])
